.trace-list-item[data-v-265b69b7]{display:flex;flex-direction:column;gap:4px;cursor:pointer;position:relative;z-index:1}.trace-list-item[data-v-265b69b7]:after{content:"";position:absolute;inset:-4px -8px;z-index:-1;border-radius:var(--radius-m)}.trace-list-item[data-v-265b69b7]:hover:after{background-color:var(--color-card-bg-dark)}.trace-item-header[data-v-265b69b7]{display:flex;align-items:center;justify-content:space-between;width:100%}.trace-time[data-v-265b69b7]{font-weight:600;color:var(--color-text-1)}.trace-id[data-v-265b69b7]{color:var(--color-text-3);font-size:.875rem}.trace-list-area[data-v-40ae747e]{display:flex;flex-direction:column;align-items:center;width:100%;height:100%;overflow-y:auto}.trace-list[data-v-40ae747e]{display:flex;width:100%;flex-direction:column;padding:12px 16px;margin-bottom:128px}.empty-state[data-v-40ae747e]{width:100%;align-self:center}.trace-item-divider[data-v-40ae747e]{margin:16px 0}.trace-list-area .float-pagination[data-v-40ae747e]{position:absolute;bottom:16px;z-index:10}.el-descriptions{--el-descriptions-table-border:1px solid var(--el-border-color-lighter);--el-descriptions-item-bordered-label-background:var(--el-fill-color-light);box-sizing:border-box;color:var(--el-text-color-primary);font-size:var(--el-font-size-base)}.el-descriptions__header{align-items:center;display:flex;justify-content:space-between;margin-bottom:16px}.el-descriptions__title{color:var(--el-text-color-primary);font-size:16px;font-weight:700}.el-descriptions__body{background-color:var(--el-fill-color-blank)}.el-descriptions__body .el-descriptions__table{border-collapse:collapse;width:100%}.el-descriptions__body .el-descriptions__table .el-descriptions__cell{box-sizing:border-box;font-size:14px;line-height:23px;text-align:left}.el-descriptions__body .el-descriptions__table .el-descriptions__cell.is-left{text-align:left}.el-descriptions__body .el-descriptions__table .el-descriptions__cell.is-center{text-align:center}.el-descriptions__body .el-descriptions__table .el-descriptions__cell.is-right{text-align:right}.el-descriptions__body .el-descriptions__table.is-bordered .el-descriptions__cell{border:var(--el-descriptions-table-border);padding:8px 11px}.el-descriptions__body .el-descriptions__table:not(.is-bordered) .el-descriptions__cell{padding-bottom:12px}.el-descriptions--large{font-size:14px}.el-descriptions--large .el-descriptions__header{margin-bottom:20px}.el-descriptions--large .el-descriptions__header .el-descriptions__title{font-size:16px}.el-descriptions--large .el-descriptions__body .el-descriptions__table .el-descriptions__cell{font-size:14px}.el-descriptions--large .el-descriptions__body .el-descriptions__table.is-bordered .el-descriptions__cell{padding:12px 15px}.el-descriptions--large .el-descriptions__body .el-descriptions__table:not(.is-bordered) .el-descriptions__cell{padding-bottom:16px}.el-descriptions--small{font-size:12px}.el-descriptions--small .el-descriptions__header{margin-bottom:12px}.el-descriptions--small .el-descriptions__header .el-descriptions__title{font-size:14px}.el-descriptions--small .el-descriptions__body .el-descriptions__table .el-descriptions__cell{font-size:12px}.el-descriptions--small .el-descriptions__body .el-descriptions__table.is-bordered .el-descriptions__cell{padding:4px 7px}.el-descriptions--small .el-descriptions__body .el-descriptions__table:not(.is-bordered) .el-descriptions__cell{padding-bottom:8px}.el-descriptions__label.el-descriptions__cell.is-bordered-label{background:var(--el-descriptions-item-bordered-label-background);color:var(--el-text-color-regular);font-weight:700}.el-descriptions__label:not(.is-bordered-label){color:var(--el-text-color-primary);margin-right:16px}.el-descriptions__label.el-descriptions__cell:not(.is-bordered-label).is-vertical-label{padding-bottom:6px}.el-descriptions__content.el-descriptions__cell.is-bordered-content{color:var(--el-text-color-primary)}.el-descriptions__content:not(.is-bordered-label){color:var(--el-text-color-regular)}.el-descriptions--large .el-descriptions__label:not(.is-bordered-label){margin-right:16px}.el-descriptions--large .el-descriptions__label.el-descriptions__cell:not(.is-bordered-label).is-vertical-label{padding-bottom:8px}.el-descriptions--small .el-descriptions__label:not(.is-bordered-label){margin-right:12px}.el-descriptions--small .el-descriptions__label.el-descriptions__cell:not(.is-bordered-label).is-vertical-label{padding-bottom:4px}.trace-detail-panel[data-v-7fb34464]{position:absolute;inset:0;z-index:20;display:flex;flex-direction:column;gap:24px;padding:12px 16px;overflow-y:auto;background:var(--color-card-bg)}.trace-detail-content[data-v-7fb34464]{display:flex;flex-direction:column;gap:16px}.span-list-title[data-v-7fb34464],[data-v-7fb34464] .span-attr-label{font-weight:600}.span-attributes-wrapper[data-v-7fb34464]{display:inline-flex;max-width:400px;overflow-x:auto}.trace-panel-wrapper[data-v-139fdbd6]{width:100%;flex:1;position:relative;overflow:hidden}
