"""add_trace_id_and_span_id

Revision ID: 2312726d56e1
Revises: 3c2f486fa1d4
Create Date: 2026-01-16 23:38:45.417339

"""
from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision: str = '2312726d56e1'
down_revision: Union[str, Sequence[str], None] = '3c2f486fa1d4'
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    """Upgrade schema."""
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column('tag', sa.Column('trace_id', sa.String(length=32), nullable=True, comment='OpenTelemetry trace_id'))
    op.add_column('tag', sa.Column('span_id', sa.String(length=16), nullable=True, comment='OpenTelemetry span_id'))
    # ### end Alembic commands ###


def downgrade() -> None:
    """Downgrade schema."""
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('tag', 'span_id')
    op.drop_column('tag', 'trace_id')
    # ### end Alembic commands ###
